import { User } from '../user';
import { AuthInfo, LoginResult, LogoutResult } from './auth.types';
/**
 * Auth is the main interface for authenticating with a Genesis Server endpoint.
 * @public
 */
export interface Auth {
    /** This property is intended to be used internally by the authentication system.
     * @internal
     * @remarks
     * TODO: For now, we are keeping `loggedUserResult` until all app and mf usages are reviewed.
     */
    readonly loggedUserResult: LoginResult;
    /**
     * A boolean value indicating whether or not the user is currently logged in.
     * @internal
     */
    readonly isLoggedIn: boolean;
    /**
     * The currently logged-in user, if any.
     * @internal
     */
    readonly currentUser: User;
    /**
     * Logs in the user with the specified credentials.
     * @public
     * @param credentials - The user's login credentials.
     * @returns A Promise that resolves to the result of the login attempt.
     * @see AuthInfo
     */
    login(credentials: AuthInfo): Promise<LoginResult>;
    /**
     * Logs out the current user, if any.
     * @public
     * @returns A Promise that resolves to the result of the logout attempt.
     * @see LogoutResult
     */
    logout(): Promise<LogoutResult>;
    /**
     * Attempts to re-authenticate the user using the existing session data.
     * @public
     * @returns A Promise that resolves to `true` if the user was successfully re-authenticated,
     * or `false` if re-authentication failed.
     */
    reAuthFromSession(): Promise<boolean>;
}
/**
 * The DI token for the Auth interface.
 * @internal
 */
export declare const Auth: import("@microsoft/fast-foundation").InterfaceSymbol<Auth>;
//# sourceMappingURL=auth.d.ts.map