/**
 * Criteria filters to fields.
 *
 * @param filters - Concatenated criteria filters.
 *
 * @public
 * @remarks
 * For filtering REQUEST_SERVER resources. Maps concatenated criteria filters from a grid to a request fields object,
 * eg: `foo == 'bar' && asd == 'zxc', into { foo: 'bar', asd: 'zxc' }`
 */
export function criteriaFiltersToFields(filters) {
    const criteria = filters.split('&&').map((s) => s.trim());
    const reqFields = {};
    criteria.forEach((c) => {
        const key = c.substr(0, c.indexOf('=')).trim().replace(/["']/g, '');
        const val = c
            .substr(c.lastIndexOf('=') + 1, c.length)
            .trim()
            .replace(/["']/g, '');
        reqFields[key] = val;
    });
    return reqFields;
}
